/*
 * This is an opaque version of the WordLoop interface
 *
 *    written by J Dean Brock, Nov 2010
 *
 */

typedef void *WordLoop ;

/*
 * Create a WordLoop from a single word.  Your program *must*
 * make a copy of that word for its "internal" use.
 * Return a NULL if this operation cannot be performed
 * due to lack of dynamic storage.
 */
WordLoop       CreateWL   (const char *) ;

/*
 * Add a word to the *end" of the WordLoop.  Again, your
 * program must make a copy of the word.  The end of the
 * WordLoop is always the last word added.  Using AdvanceWL
 * or NextWordWL never changes the end of the WordLoop.
 * Return a non-zero value if this operation cannot be
 * performed due to lack of dynamic storage.
 */
int            AddWordWL  (WordLoop, const char *) ;

/*
 * Obtain the next word from the WordLoop.  The calling
 * program should *never* modify the returned value.
 */
const char *   NextWordWL (WordLoop) ;

/*
 * Advance the "pointer" to the next word of the WordLoop.
 */
void     AdvanceWL  (WordLoop) ;

/*
 * Delete all space used by the WordLoop.  Obviously, the
 * WordLoop should not be used after this call.
 */
void     DestroyWL  (WordLoop) ;
